@@ -4,7 +4,7 @@ import requests
 
 
 class Model(object):
-    SERVER_HOST = None
+    SERVER_HOST = "achilles.insnail.com"
     PROTOCOL = "https"  # or http
 
     def __init__(self, project_slug, model_slug, version):
